@@ -2,8 +2,10 @@
 DSLIBRARY - run your data science code anywhere.
 
 """
-__version__ = "0.0.27"
+__version__ = "0.0.28"
 
+# exceptions
+from .exceptions import *
 # environment variables
 from .front import ENV_DSLIBRARY_TARGET, ENV_DSLIBRARY_SPEC, ENV_DSLIBRARY_TOKEN
 # main base class
