@@ -19,12 +19,13 @@ import warnings
 import urllib.parse
 import shutil
 
+from .exceptions import DSLibraryDataFormatException, DSLibraryException
 from .engine_intf import GenericStreamWrapper, BytesIOWrapper
 from .proto_handlers import load_protocol_handler
 from .utils.connect import connect_to_database, dataframe_to_sql
 from .utils.dbconn import sql_enquote_id
 from .utils.file_utils import write_stream_with_read_on_close, connect_to_filesystem
-from .utils.format_sniffer import find_url_extension, detect_format, looks_like_text_file
+from .utils.format_sniffer import find_url_extension, detect_format
 from .utils.nosql import connect_to_nosql
 from .utils.packages import install_packages
 
@@ -919,12 +920,14 @@ class DSLibrary(object):
             except IsADirectoryError:
                 pass
         def sizer():
-            with use_opener(resource_name, mode='rb') as f_r:
+            with use_opener(resource_name, mode='rb', **open_args) as f_r:
                 if not hasattr(f_r, "seek") or not f_r.seekable():
                     return
-                f_r.seek(0, 2)
-                return f_r.tell()
-        # FIXME detect non-seekable stream and inhibit sampling/sizing
+                try:
+                    f_r.seek(0, 2)
+                    return f_r.tell()
+                except:
+                    return
         # sniff format
         use_sizer = use_dask > 1
         format_info = detect_format(
@@ -937,7 +940,8 @@ class DSLibrary(object):
             if format_info.size is not None:
                 use_dask = format_info.size > use_dask
             else:
-                use_dask = 0
+                # size unknown - use dask if dask limit was set to a particularly low value
+                use_dask = 10000 > use_dask
         # various formats and their read function
         if use_dask:
             use_dask = format in DASK_READ_FORMATS
@@ -1038,28 +1042,6 @@ class DSLibrary(object):
     #   mlflow = dslibrary.instance()
 
 
-class DSLibraryException(Exception):
-    """
-    General errors.
-    """
-
-
-class DSLibraryDataFormatException(DSLibraryException):
-    """
-    Problems with data
-    """
-    def __init__(self, message: str, offset: int=None):
-        super(DSLibraryDataFormatException, self).__init__(message, offset)
-        self.message = message
-        self.offset = offset
-
-
-class DSLibraryCommunicationError(DSLibraryException):
-    """
-    Communication errors.
-    """
-
-
 LOCAL_SPECS_SCHEMA = {
     "comment": "Parameter values, and format/mapping information for inputs and outputs, as well as every other configurable run option is defined here.",
     "type": "object",
