@@ -7,6 +7,7 @@ import pandas
 import shutil
 import tempfile
 import yaml
+import dask.dataframe
 
 from dslibrary import DSLibrary
 from dslibrary.front import EVALUATION_RESULT_ALIAS, METRICS_ALIAS, DSLibraryException, DSLibraryDataFormatException
@@ -626,3 +627,45 @@ class TestFront(unittest.TestCase):
             self.fail("expected error")
         except DSLibraryDataFormatException as err:
             assert "JSON format error" in err.message
+
+    def test_rw_folder(self):
+        """
+        Dask writes data into folders, in the manner of spark.
+        """
+        for dataframe_type in ("p", "d"):
+            tmpdir = tempfile.mkdtemp()
+            try:
+                class MyInst(DSLibrary):
+                    def _opener(self, path: str, mode: str, **kwargs):
+                        return open(path, mode)
+                fn = os.path.join(tmpdir, "x.csv")
+                df = pandas.DataFrame({"x": list(range(100))})
+                if dataframe_type == "d":
+                    df = dask.dataframe.from_pandas(df, npartitions=2)
+                parts = MyInst().write_resource(fn, df, dask=True)
+                self.assertEqual(os.listdir(tmpdir), ["x.csv"])
+                if dataframe_type == "d":
+                    self.assertEqual(os.listdir(fn), ["0.part", "1.part"])
+                    assert len(parts) == 2
+                else:
+                    self.assertEqual(os.listdir(fn), ["0.part"])
+                    assert len(parts) == 1
+                df = MyInst().load_dataframe(fn, dask=True, format_options={"delimiter": "\n"}).compute()
+                self.assertEqual(list(df.x), list(range(100)))
+            finally:
+                shutil.rmtree(tmpdir)
+
+    def test_write_dask_csv(self):
+        """
+        Dask is able to write to a single CSV file.
+        """
+        files = {}
+        class MyInst(DSLibrary):
+            def _opener(self, path: str, mode: str, **kwargs):
+                files[path] = fh = io.BytesIO()
+                fh.close = lambda: None
+                return fh
+        df = pandas.DataFrame({"x": list(range(7))})
+        MyInst().write_resource("x.csv", dask.dataframe.from_pandas(df, npartitions=2), dask=False)
+        self.assertEqual(files["x.csv"].getvalue(), b"x\n0\n1\n2\n3\n4\n5\n6\n")
+
